@@ -5,7 +5,7 @@ use Moo;
 use DateTime;
 use Log::Any '$log';
 
-our $VERSION = '0.36'; # VERSION
+our $VERSION = '0.37'; # VERSION
 
 extends 'Finance::Bank::ID::Base';
 
@@ -402,20 +402,20 @@ sub _ps_get_transactions {
 
         if ($self->_variant eq 'perorangan' &&
             $tx->{date}->dow =~ /6|7/ &&
-            $tx->{description} !~ /^(BIAYA ADM|BUNGA|(CR|DR) KOREKSI BUNGA|PAJAK BUNGA)$/) {
+            $tx->{description} !~ /^(BIAYA ADM|BUNGA|(CR|DR) KOREKSI BUNGA|PAJAK BUNGA)\s*$/) {
             return "check failed in tx#$i: In KlikBCA Perorangan, all ".
                 "transactions must not be in Sat/Sun except for Interest and ".
-                "Admin Fee: $tx->{description} ($tx->{date})";
+                "Admin Fee: <$tx->{description}> ($tx->{date})";
             # note: in Tahapan perorangan, BIAYA ADM is set on
             # Fridays, but for Tapres (?) on last day of the month
         }
 
         if ($self->_variant eq 'bisnis' &&
             $tx->{date}->dow =~ /6|7/ &&
-            $tx->{description} !~ /^(BIAYA ADM|BUNGA|(CR|DR) KOREKSI BUNGA|PAJAK BUNGA)$/) {
+            $tx->{description} !~ /^(BIAYA ADM|BUNGA|(CR|DR) KOREKSI BUNGA|PAJAK BUNGA)\s*$/) {
             return "check failed in tx#$i: In KlikBCA Bisnis, all ".
                 "transactions must not be in Sat/Sun except for Interest and ".
-                "Admin Fee";
+                "Admin Fee: <$tx->{description}> ($tx->{date})";
             # note: in KlikBCA bisnis, BIAYA ADM is set on the last day of the
             # month, regardless of whether it's Sat/Sun or not
         }
@@ -447,7 +447,7 @@ Finance::Bank::ID::BCA - Check your BCA accounts from Perl
 
 =head1 VERSION
 
-This document describes version 0.36 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2015-04-29.
+This document describes version 0.37 of Finance::Bank::ID::BCA (from Perl distribution Finance-Bank-ID-BCA), released on 2015-06-09.
 
 =head1 SYNOPSIS
 
